@@ -15,6 +15,7 @@
 #include <sys/time.h>		/* FreeBSD wants this for the next one.. */
 #include <sys/resource.h>
 #include <poll.h>
+#include <time.h>
 
 #if !defined(WCOREDUMP)
 # define WCOREDUMP(x) 0
@@ -29,7 +30,7 @@
 #include "target.h"
 #include "term.h"
 
-static char const rcsid[] = "@(#)$Id: loop.c 1538 2008-12-18 16:13:19Z kalt $";
+static char const rcsid[] = "@(#)$Id$";
 
 extern char *myname;
 
@@ -511,21 +512,23 @@ struct child *children;
 	  spawn_mode = SPAWN_PAUSE;
 	  break;
       case '1':
-	  if (spawn_mode != SPAWN_ONE)
+	  if (spawn_mode != SPAWN_ONE) {
               if (failure_mode == SPAWN_PAUSE)
                   uprint("Will spawn one command... (And pause on error)");
               else
                   uprint("Will spawn one command... (And quit on error)");
+    }
 	  if (spawn_mode != SPAWN_NONE)
 	      spawn_mode = SPAWN_ONE;
 	  break;
       case '\n':
       case '-':
-	  if (spawn_mode != SPAWN_CHECK)
+	  if (spawn_mode != SPAWN_CHECK) {
               if (failure_mode == SPAWN_PAUSE)
                   uprint("Resuming... (Will pause on error)");
               else
                   uprint("Resuming... (Will quit on error)");
+    }
 	  spawn_mode = SPAWN_CHECK;
 	  break;
       case '+':
@@ -1008,9 +1011,12 @@ u_int ctimeout, utest;
 		    */
 		    char buffer[8192];
 		    int sz;
+        int err = 0;
 
 		    sz = read(pfd[idx].fd, buffer, (idx == 0) ? 1 : 8191);
-		    dprint("idx=%d[%s] fd=%d(%d) read()=%d",
+        if (sz < 0)
+          err = errno;
+        dprint("idx=%d[%s] fd=%d(%d) read()=%d",
 			   idx, what, pfd[idx].fd, idx%3, sz);
 		    if (sz > 0)
 		      {
@@ -1030,15 +1036,17 @@ u_int ctimeout, utest;
 				eprint("Unexpected empty read(/dev/tty) result");
 			    else
 				eprint("Unexpected read(/dev/tty) error for: %s",
-				       strerror(errno));
-			    if (sz == 0 || errno != EINTR)
+				       strerror(err));
+			    if (sz == 0 || err != EINTR) {
 				tty_restore();
+          }
 #else
 			    if (sz != 0)
 				eprint("Unexpected read(/dev/tty) error for: %s",
-				       strerror(errno));
-			    if (errno != EINTR)
+				       strerror(err));
+			    if (err != 0 && err != EINTR) {
 				tty_restore();
+          }
 #endif
 			  }
 			else
