@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2002-2008 Christophe Kalt
+** Copyright (C) 2002-2017 Christophe Kalt
 **
 ** This file is part of shmux,
 ** see the LICENSE file for details on your rights.
@@ -8,6 +8,7 @@
 #include "os.h"
 
 #include <ctype.h>
+#include <time.h>
 
 #include "target.h"
 #include "term.h"
@@ -15,7 +16,7 @@
 #include "status.h"
 #include "units.h"
 
-static char const rcsid[] = "@(#)$Id: target.c 1435 2008-04-03 01:43:18Z kalt $";
+static char const rcsid[] = "@(#)$Id$";
 
 extern char *myname;
 
@@ -30,7 +31,7 @@ struct target
 			**  2	test		test okay
 			**  3	cmd		cmd done, exit status okay
 			**  4   analyzer	all done
-			*/    
+			*/
     char status;
     char phase;
     time_t when;
@@ -279,7 +280,7 @@ char **args;
     ** Use buf to store NUL delimited copy of opts,
     ** filling up args as we go along.
     */
-    
+
     i = 0;
     while (*opts)
       {
@@ -457,7 +458,8 @@ char *cmd;
       {
 	args[4] = "-x";
         args[5] = "-a";
-	nopts = 2;
+        args[6] = "-oLogLevel=ERROR";
+	nopts = 3;
       }
     args[4 + nopts] = targets[tcur].name;
     args[5 + nopts] = cmd;
